@@ -484,6 +484,7 @@ class Histogram(BaseHistogram):
         slices = []
         zeroes_start = []
         zeroes_stop = []
+        pick = dict()
 
         # We could use python's sum here, but for now, a private sum is used
         class ext_sum:
@@ -492,7 +493,8 @@ class Histogram(BaseHistogram):
         # Compute needed slices and projections
         for i, ind in iterator:
             if hasattr(ind, "__index__"):
-                ind = slice(ind.__index__(), ind.__index__() + 1, ext_sum())
+                pick[i] = ind.__index__()
+                ind = slice(None)
 
             elif not isinstance(ind, slice):
                 raise IndexError(
@@ -508,6 +510,8 @@ class Histogram(BaseHistogram):
                                 zeroes_start.append(i)
                             if ind.stop is not None:
                                 zeroes_stop.append(i)
+                            if ind.stop is None and ind.start is None:
+                                continue
                         elif hasattr(ind.step, "factor"):
                             merge = ind.step.factor
                         else:
@@ -530,25 +534,53 @@ class Histogram(BaseHistogram):
                 slices.append(_core.algorithm.slice_and_rebin(i, begin, end, merge))
 
         reduced = self._reduce(*slices)
+
         if not integrations:
-            return self.__class__(reduced)
+            result = self.__class__(reduced)
         else:
             projections = [i for i in range(self.rank) if i not in integrations]
 
+            # For each axes projected out, we need to lower "pick" since it
+            # operates after the projection
+            reduce_ax = lambda ax: sum(i in projections for i in range(ax))
+            pick = {reduce_ax(ax): pick[ax] for ax in pick}
+
             # Replacement for crop missing in BH
             for i in zeroes_start:
                 if self.axes[i].options.underflow:
                     reduced._hist._reset_row(i, -1)
             for i in zeroes_stop:
-                if self.axes[i].options.underflow:
+                if self.axes[i].options.overflow:
                     reduced._hist._reset_row(i, reduced.axes[i].size)
 
-            return (
+            result = (
                 self.__class__(reduced.project(*projections))
                 if projections
                 else reduced.sum(flow=True)
             )
 
+        # Allow user to "pick" out values when mixed with slices
+        if pick:
+            # Sum out the axes. We will replace the contents, so "drop" would be
+            # just as good if there was one.
+            sresult = result[{ax: slice(None, None, ext_sum()) for ax in pick}]
+
+            # Make an array of selections, starting with [:,:,...,:]
+            bins_indexes = [slice(None)] * result.rank
+            # Now make the axis selections, remembering we will be in flow view
+            for ax in pick:
+                bins_indexes[ax] = pick[ax] + result._axis(ax).options.underflow
+
+            # If the result is a single value, we need to avoid [...]
+            if hasattr(sresult, "rank"):
+                sresult[...] = result.view(flow=True)[tuple(bins_indexes)]
+            else:
+                sresult = result.view(flow=True)[tuple(bins_indexes)]
+
+            result = sresult
+
+        return result
+
     def __setitem__(self, index, value):
         """
         There are several supported possibilities:
